@@ -1,12 +1,11 @@
 import sys
 import os
-import json
 import subprocess
 
 from sys import platform
 from importlib import resources
 
-from functions import check_quiet_print
+from ansurr.functions import check_quiet_print
 
 def calc_secondary_structure(pdb,output_dir='',quiet=False):
 
